@@ -1,5 +1,3 @@
-import numpy as np
-import pandas as pd
 import tqdm 
 
 class nqdm(tqdm.tqdm):
@@ -206,6 +204,8 @@ class nqdm(tqdm.tqdm):
         is_constant = lambda y: any([x == "as_integer_ratio" for x in y.__dict__]) if hasattr(y, '__dict__') else False
         is_string = lambda y: y == str
 
+        argmax = lambda x: max(zip(x, range(len(x))))[1]
+
         # List of functions
         functions = [is_iterable, is_hashable, is_constant, is_string]
 
@@ -217,15 +217,15 @@ class nqdm(tqdm.tqdm):
             return y_i, type(y_i)
 
         # Convert to list
-        if np.argmax(y) == 0:
+        if argmax(y) == 0:
             return list(y_i), "list" 
         
         # Conversion to dict
-        if np.argmax(y) == 1:
+        if argmax(y) == 1:
             return dict(y_i), "dict"
         
         # Check if int or not given that it is a constant
-        if np.argmax(y) == 2:
+        if argmax(y) == 2:
             if type(y_i) == int:
                 return y_i, "int"
             else:
@@ -233,7 +233,7 @@ class nqdm(tqdm.tqdm):
                 return y_i, "float"
         
         # Conversion of string to list
-        if np.argmax(y) == 3:
+        if argmax(y) == 3:
             return list(y_i), "string"
         
     def __limit__(self):
